@@ -24,6 +24,7 @@ import os
 import pty
 import shutil
 import sys
+import tempfile
 import unittest
 
 from tests.common import build_temp_workspace
@@ -72,6 +73,9 @@ class CommandLineTestCase(unittest.TestCase):
             # file in dir
             'sub/ok.yaml': '---\n'
                            'key: value\n',
+            # directory that looks like a yaml file
+            'sub/directory.yaml/not-yaml.txt': '',
+            'sub/directory.yaml/empty.yml': '',
             # file in very nested dir
             's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml': '---\n'
                                                        'key: value\n'
@@ -91,6 +95,13 @@ class CommandLineTestCase(unittest.TestCase):
             # dos line endings yaml
             'dos.yml': '---\r\n'
                        'dos: true',
+            # different key-ordering by locale
+            'c.yaml': '---\n'
+                      'A: true\n'
+                      'a: true',
+            'en.yaml': '---\n'
+                       'a: true\n'
+                       'A: true'
         })
 
     @classmethod
@@ -104,9 +115,12 @@ class CommandLineTestCase(unittest.TestCase):
         self.assertEqual(
             sorted(cli.find_files_recursively([self.wd], conf)),
             [os.path.join(self.wd, 'a.yaml'),
+             os.path.join(self.wd, 'c.yaml'),
              os.path.join(self.wd, 'dos.yml'),
              os.path.join(self.wd, 'empty.yml'),
+             os.path.join(self.wd, 'en.yaml'),
              os.path.join(self.wd, 's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml'),
+             os.path.join(self.wd, 'sub/directory.yaml/empty.yml'),
              os.path.join(self.wd, 'sub/ok.yaml'),
              os.path.join(self.wd, 'warn.yaml')],
         )
@@ -131,6 +145,7 @@ class CommandLineTestCase(unittest.TestCase):
         self.assertEqual(
             sorted(cli.find_files_recursively(items, conf)),
             [os.path.join(self.wd, '/etc/another/file'),
+             os.path.join(self.wd, 'sub/directory.yaml/empty.yml'),
              os.path.join(self.wd, 'sub/ok.yaml')],
         )
 
@@ -140,6 +155,8 @@ class CommandLineTestCase(unittest.TestCase):
         self.assertEqual(
             sorted(cli.find_files_recursively([self.wd], conf)),
             [os.path.join(self.wd, 'a.yaml'),
+             os.path.join(self.wd, 'c.yaml'),
+             os.path.join(self.wd, 'en.yaml'),
              os.path.join(self.wd, 's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml'),
              os.path.join(self.wd, 'sub/ok.yaml'),
              os.path.join(self.wd, 'warn.yaml')]
@@ -151,7 +168,8 @@ class CommandLineTestCase(unittest.TestCase):
         self.assertEqual(
             sorted(cli.find_files_recursively([self.wd], conf)),
             [os.path.join(self.wd, 'dos.yml'),
-             os.path.join(self.wd, 'empty.yml')]
+             os.path.join(self.wd, 'empty.yml'),
+             os.path.join(self.wd, 'sub/directory.yaml/empty.yml')]
         )
 
         conf = config.YamlLintConfig('extends: default\n'
@@ -168,11 +186,15 @@ class CommandLineTestCase(unittest.TestCase):
         self.assertEqual(
             sorted(cli.find_files_recursively([self.wd], conf)),
             [os.path.join(self.wd, 'a.yaml'),
+             os.path.join(self.wd, 'c.yaml'),
              os.path.join(self.wd, 'dos.yml'),
              os.path.join(self.wd, 'empty.yml'),
+             os.path.join(self.wd, 'en.yaml'),
              os.path.join(self.wd, 'no-yaml.json'),
              os.path.join(self.wd, 'non-ascii/éçäγλνπ¥/utf-8'),
              os.path.join(self.wd, 's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml'),
+             os.path.join(self.wd, 'sub/directory.yaml/empty.yml'),
+             os.path.join(self.wd, 'sub/directory.yaml/not-yaml.txt'),
              os.path.join(self.wd, 'sub/ok.yaml'),
              os.path.join(self.wd, 'warn.yaml')]
         )
@@ -185,11 +207,15 @@ class CommandLineTestCase(unittest.TestCase):
         self.assertEqual(
             sorted(cli.find_files_recursively([self.wd], conf)),
             [os.path.join(self.wd, 'a.yaml'),
+             os.path.join(self.wd, 'c.yaml'),
              os.path.join(self.wd, 'dos.yml'),
              os.path.join(self.wd, 'empty.yml'),
+             os.path.join(self.wd, 'en.yaml'),
              os.path.join(self.wd, 'no-yaml.json'),
              os.path.join(self.wd, 'non-ascii/éçäγλνπ¥/utf-8'),
              os.path.join(self.wd, 's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml'),
+             os.path.join(self.wd, 'sub/directory.yaml/empty.yml'),
+             os.path.join(self.wd, 'sub/directory.yaml/not-yaml.txt'),
              os.path.join(self.wd, 'sub/ok.yaml'),
              os.path.join(self.wd, 'warn.yaml')]
         )
@@ -285,6 +311,58 @@ class CommandLineTestCase(unittest.TestCase):
             cli.run((os.path.join(self.wd, 'a.yaml'), ))
         self.assertEqual(ctx.returncode, 1)
 
+    def test_run_with_user_yamllint_config_file_in_env(self):
+        self.addCleanup(os.environ.__delitem__, 'YAMLLINT_CONFIG_FILE')
+
+        with tempfile.NamedTemporaryFile('w') as f:
+            os.environ['YAMLLINT_CONFIG_FILE'] = f.name
+            f.write('rules: {trailing-spaces: disable}')
+            f.flush()
+            with RunContext(self) as ctx:
+                cli.run((os.path.join(self.wd, 'a.yaml'), ))
+            self.assertEqual(ctx.returncode, 0)
+
+        with tempfile.NamedTemporaryFile('w') as f:
+            os.environ['YAMLLINT_CONFIG_FILE'] = f.name
+            f.write('rules: {trailing-spaces: enable}')
+            f.flush()
+            with RunContext(self) as ctx:
+                cli.run((os.path.join(self.wd, 'a.yaml'), ))
+            self.assertEqual(ctx.returncode, 1)
+
+    def test_run_with_locale(self):
+        self.addCleanup(locale.setlocale, locale.LC_ALL, 'C.UTF-8')
+        try:
+            locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
+        except locale.Error:
+            self.skipTest('locale en_US.UTF-8 not available')
+
+        # C + en.yaml should fail
+        with RunContext(self) as ctx:
+            cli.run(('-d', 'rules: { key-ordering: enable }',
+                     os.path.join(self.wd, 'en.yaml')))
+        self.assertEqual(ctx.returncode, 1)
+
+        # en_US + en.yaml should pass
+        with RunContext(self) as ctx:
+            cli.run(('-d', 'locale: en_US.UTF-8\n'
+                           'rules: { key-ordering: enable }',
+                     os.path.join(self.wd, 'en.yaml')))
+        self.assertEqual(ctx.returncode, 0)
+
+        # en_US + c.yaml should fail
+        with RunContext(self) as ctx:
+            cli.run(('-d', 'locale: en_US.UTF-8\n'
+                           'rules: { key-ordering: enable }',
+                     os.path.join(self.wd, 'c.yaml')))
+        self.assertEqual(ctx.returncode, 1)
+
+        # C + c.yaml should pass
+        with RunContext(self) as ctx:
+            cli.run(('-d', 'rules: { key-ordering: enable }',
+                    os.path.join(self.wd, 'c.yaml')))
+        self.assertEqual(ctx.returncode, 0)
+
     def test_run_version(self):
         with RunContext(self) as ctx:
             cli.run(('--version', ))
@@ -343,15 +421,6 @@ class CommandLineTestCase(unittest.TestCase):
     def test_run_non_ascii_file(self):
         path = os.path.join(self.wd, 'non-ascii', 'éçäγλνπ¥', 'utf-8')
 
-        # Make sure the default localization conditions on this "system"
-        # support UTF-8 encoding.
-        loc = locale.getlocale()
-        try:
-            locale.setlocale(locale.LC_ALL, 'C.UTF-8')
-        except locale.Error:
-            locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
-        self.addCleanup(locale.setlocale, locale.LC_ALL, loc)
-
         with RunContext(self) as ctx:
             cli.run(('-f', 'parsable', path))
         self.assertEqual((ctx.returncode, ctx.stdout, ctx.stderr), (0, '', ''))
